@@ -11,8 +11,9 @@ import ctypes.util
 import itertools
 import os
 import os.path
-import sys
 import platform
+import sys
+import traceback
 
 __all__ = ('MagickPixelPacket', 'c_magick_char_p', 'library', 'libc',
            'libmagick', 'load_library')
@@ -291,6 +292,11 @@ try:
 
     library.MagickSetImageColorspace.argtypes = [ctypes.c_void_p, ctypes.c_int]
 
+    library.MagickGetImageCompression.argtypes = [ctypes.c_void_p]
+    library.MagickGetImageCompression.restype = ctypes.c_int
+
+    library.MagickSetImageCompression.argtypes = [ctypes.c_void_p, ctypes.c_int]
+
     library.MagickGetImageDepth.argtypes = [ctypes.c_void_p]
     library.MagickGetImageDepth.restype = ctypes.c_size_t
 
@@ -720,6 +726,12 @@ try:
                                  ctypes.c_double,
                                  ctypes.c_double]
 
+    library.DrawRectangle.argtypes = [ctypes.c_void_p,
+                                      ctypes.c_double,
+                                      ctypes.c_double,
+                                      ctypes.c_double,
+                                      ctypes.c_double]
+
     library.DrawAnnotation.argtypes = [ctypes.c_void_p,
                                        ctypes.c_double,
                                        ctypes.c_double,
@@ -742,7 +754,9 @@ try:
         ctypes.c_double
     )
 except AttributeError:
-    raise ImportError('MagickWand shared library not found or incompatible')
+    raise ImportError('MagickWand shared library not found or incompatible\n'
+                      'Original exception was raised in:\n' +
+                      traceback.format_exc())
 
 #: (:class:`ctypes.CDLL`) The C standard library.
 libc = None
@@ -758,6 +772,7 @@ else:
         libc = ctypes.cdll.LoadLibrary('libc.so.6')
     libc.fdopen.argtypes = [ctypes.c_int, ctypes.c_char_p]
     libc.fdopen.restype = ctypes.c_void_p
+    libc.fflush.argtypes = [ctypes.c_void_p]
 
 libc.free.argtypes = [ctypes.c_void_p]
 
